@@ -13,9 +13,13 @@ from functools import update_wrapper
 import click
 import requests
 
-from apigee import (APIGEE_CLI_EXCEPTIONS_LOG_FILE,
-                    APIGEE_CLI_PLUGINS_DIRECTORY, APIGEE_CLI_PLUGINS_PATH, APP,
-                    CMD)
+from apigee import (
+    APIGEE_CLI_EXCEPTIONS_LOG_FILE,
+    APIGEE_CLI_PLUGINS_DIRECTORY,
+    APIGEE_CLI_PLUGINS_PATH,
+    APP,
+    CMD,
+)
 from apigee import __version__ as version
 from apigee.apiproducts.commands import apiproducts
 from apigee.apis.commands import apis
@@ -37,21 +41,28 @@ from apigee.references.commands import references
 from apigee.sharedflows.commands import sharedflows
 from apigee.targetservers.commands import targetservers
 from apigee.userroles.commands import userroles
-from apigee.utils import (import_all_modules_in_directory, is_dir,
-                          run_func_on_dir_files, show_message)
+from apigee.utils import (
+    import_all_modules_in_directory,
+    is_dir,
+    run_func_on_dir_files,
+    show_message,
+)
 from apigee.virtualhosts.commands import virtualhosts
 
 # from click_aliases import ClickAliasedGroup
 
 
-CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
+CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
 
 @click.group(
-    context_settings=CONTEXT_SETTINGS, cls=AliasedGroup, invoke_without_command=False, chain=False
+    context_settings=CONTEXT_SETTINGS,
+    cls=AliasedGroup,
+    invoke_without_command=False,
+    chain=False,
 )
 # @click.group(context_settings=CONTEXT_SETTINGS, cls=ClickAliasedGroup, invoke_without_command=False, chain=False)
-@click.version_option(version, '-V', '--version')
+@click.version_option(version, "-V", "--version")
 @click.pass_context
 def cli(ctx):
     """Welcome to the (Unofficial) Apigee Management API command-line interface!
@@ -100,7 +111,7 @@ def main():
         APIGEE_CLI_PLUGINS_DIRECTORY,
         import_all_modules_in_directory,
         args=(cli_commands,),
-        glob='[!.][!__]*/__init__.py',
+        glob="[!.][!__]*/__init__.py",
     )
 
     for command in cli_commands:
@@ -109,6 +120,6 @@ def main():
     cli(prog_name=CMD, obj={})
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # cli() # pragma: no cover
     main()  # pragma: no cover
