@@ -11,10 +11,4 @@ class AliasedGroup(click.Group):
             return None
         elif len(matches) == 1:
             return click.Group.get_command(self, ctx, matches[0])
-        ctx.fail('Too many matches: %s' % ', '.join(sorted(matches)))
-
-
-class OptionEatAll(click.Option):
-    """https://stackoverflow.com/a/48394004"""
-
-    pass
+        ctx.fail("Too many matches: %s" % ", ".join(sorted(matches)))
