@@ -13,18 +13,14 @@ class InvalidApisError(Exception):
     pass
 
 
-class NotYetImplementedError(Exception):
-    pass
-
-
 def setup_global_logger(log_file):
     touch(log_file)
+    remove_file_above_size(log_file, size_kb=1000)
     logging.basicConfig(
         filename=log_file,
         level=logging.WARNING,
-        format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
+        format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
     )
-    remove_file_above_size(log_file, size_kb=1000)
 
 
 def exception_handler(func):
@@ -34,11 +30,13 @@ def exception_handler(func):
             result = func(*args, **kwargs)
             return result
         except Exception as e:
-            logging.error('Exception occurred', exc_info=True)
+            logging.error("Exception occurred", exc_info=True)
             frm = inspect.trace()[-1]
             mod = inspect.getmodule(frm[0])
             modname = mod.__name__ if mod else frm[1]
-            sys.exit(f'An exception of type {modname}.{type(e).__name__} occurred. Arguments:\n{e}')
+            sys.exit(
+                f"An exception of type {modname}.{type(e).__name__} occurred. Arguments:\n{e}"
+            )
         except KeyboardInterrupt:
             console.echo()
             sys.exit(130)
