@@ -4,15 +4,17 @@ import json
 class ReferencesSerializer:
     def serialize_details(self, references, format, prefix=None):
         resp = references
-        if format == 'text':
+        if format == "text":
             return references.text
         references = references.json()
         if prefix:
-            references = [reference for reference in references if reference.startswith(prefix)]
-        if format == 'json':
+            references = [
+                reference for reference in references if reference.startswith(prefix)
+            ]
+        if format == "json":
             return json.dumps(references)
-        elif format == 'table':
+        elif format == "table":
             pass
-        elif format == 'dict':
+        elif format == "dict":
             return references
         return resp
